from django.http import HttpResponseRedirect
from django.views.generic.simple import direct_to_template
from django.views.generic.list_detail import object_list
from forms import PhotoUserSearchForm, PhotoUserMonthSearchForm, UserCreationForm
from photo.models import Photo

def user_name_join(request):
    if request.method == 'POST':
        form = PhotoUserSearchForm(request.POST)
        if form.is_valid():
            queryset = Photo.objects.filter(owner__first_name=form.cleaned_data['first_name'],
                                            owner__last_name=form.cleaned_data['last_name'])
            return object_list(request, template_object_name='photo',
                               queryset=queryset)
    else:
        form = PhotoUserSearchForm()
    
    return direct_to_template(request, 'demo_simple_joins/search.html',
        {'user_search_form': form,
         'user_popular_search_form': PhotoUserSearchForm(),
         'user_month_search_form': PhotoUserMonthSearchForm()})

def popular_user_name_join(request):
    if request.method == 'POST':
        form = PhotoUserSearchForm(request.POST)
        if form.is_valid():
            queryset = Photo.objects.filter(owner__first_name=form.cleaned_data['first_name'],
                                            owner__last_name=form.cleaned_data['last_name'],
                                            popularity=2)
   
            return object_list(request, template_object_name='photo',
                               queryset=queryset)
    else:
        form = PhotoUserSearchForm()
    
    return direct_to_template(request, 'demo_simple_joins/search.html',
        {'user_search_form': PhotoUserSearchForm(),
         'user_popular_search_form': form,
         'user_month_search_form': PhotoUserMonthSearchForm()})

def complex_join(request):
    if request.method == 'POST':
        form = PhotoUserMonthSearchForm(request.POST)
        if form.is_valid():
            queryset = Photo.objects.filter(owner__first_name__iexact=form.cleaned_data['first_name'],
                                            owner__last_name__iexact=form.cleaned_data['last_name'],
                                            published__month=form.cleaned_data['month'], popularity=2)
            return object_list(request, template_object_name='photo',
                               queryset=queryset)
    else:
        form = PhotoUserMonthSearchForm()
    
    return direct_to_template(request, 'demo_simple_joins/search.html',
        {'user_search_form': PhotoUserSearchForm(),
         'user_popular_search_form': PhotoUserSearchForm(),
         'user_month_search_form': form})

def create_new_user(request):
    if request.method == 'POST':
        form = UserCreationForm(request.POST)
        if form.is_valid():
            form.save()
            return HttpResponseRedirect('/')
    else:
        form = UserCreationForm()
    return direct_to_template(request, 'demo_simple_joins/user_create_form.html',
        {'form': form})
